==> es-2.8.1.zip: es/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Ir al contenido';
$GLOBALS['__l10n']['To menu'] = 'Ir al menú';
$GLOBALS['__l10n']['To search'] = 'Ir a las búsquedas';
$GLOBALS['__l10n']['By'] = 'Por';
$GLOBALS['__l10n']['by'] = 'por';
$GLOBALS['__l10n']['on'] = 'el';
$GLOBALS['__l10n']['On'] = 'El';
$GLOBALS['__l10n']['Continue reading'] = 'Seguir leyendo';
$GLOBALS['__l10n']['no comments'] = 'sin comentarios';
$GLOBALS['__l10n']['one comment'] = 'un comentario';
$GLOBALS['__l10n']['%d comments'] = '%d comentarios';
$GLOBALS['__l10n']['no trackbacks'] = 'sin retroenlaces';
$GLOBALS['__l10n']['one trackback'] = 'un retroenlace';
$GLOBALS['__l10n']['%d trackbacks'] = '%d retroenlaces';
$GLOBALS['__l10n']['no attachments'] = 'sin adjuntos';
$GLOBALS['__l10n']['one attachment'] = 'un adjunto';
$GLOBALS['__l10n']['%d attachments'] = '%d adjuntos';
$GLOBALS['__l10n']['previous entries'] = 'entradas anteriores';
$GLOBALS['__l10n']['page'] = 'página';
$GLOBALS['__l10n']['of'] = 'de';
$GLOBALS['__l10n']['next entries'] = 'siguientes entradas';
$GLOBALS['__l10n']['Search'] = 'Buscar';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Su busqueda de <em>%1$s</em> no ha devuelto ningún resultado.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Su búsqueda de <em>%1$s</em> ha devuelto <strong>%2$s</strong> resultado.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Su búsqueda de <em>%1$s</em> ha devuelto <strong>%2$s</strong> resultados.';
$GLOBALS['__l10n']['Home'] = 'Inicio';
$GLOBALS['__l10n']['All keywords'] = 'Todas las palabras clave';
$GLOBALS['__l10n']['Best of me'] = 'Destacados';
$GLOBALS['__l10n']['Languages'] = 'Idiomas';
$GLOBALS['__l10n']['Categories'] = 'Categorías';
$GLOBALS['__l10n']['Subcategories'] = 'Subcategorías';
$GLOBALS['__l10n']['Archives'] = 'Archivos';
$GLOBALS['__l10n']['Links'] = 'Enlaces';
$GLOBALS['__l10n']['Subscribe'] = 'Suscribirse';
$GLOBALS['__l10n']['Entries feed'] = 'Fuente de las entradas';
$GLOBALS['__l10n']['Comments feed'] = 'Fuente de los comentarios';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Fuente Atom de los comentarios de este blog';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Fuente Atom de las entradas de esta categoría';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Fuente Atom de los comentarios de esta categoría';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Fuente de los comentarios de esta entrada';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Fuente Atom de los comentarios de esta entrada';
$GLOBALS['__l10n']['Attachments'] = 'Adjuntos';
$GLOBALS['__l10n']['Permalink'] = 'Enlace permanente';
$GLOBALS['__l10n']['Comments'] = 'Comentarios';
$GLOBALS['__l10n']['Your comment'] = 'Su comentario';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Su comentario ha sido publicado.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Se ha enviado su comentario, y se publicará tras ser revisado.';
$GLOBALS['__l10n']['Add a comment'] = 'Añadir un comentario';
$GLOBALS['__l10n']['Name or nickname'] = 'Nombre o apodo';
$GLOBALS['__l10n']['Email address'] = 'Dirección de correo electrónico';
$GLOBALS['__l10n']['Website'] = 'Sitio web';
$GLOBALS['__l10n']['optional'] = 'opcional';
$GLOBALS['__l10n']['Comment'] = 'Comentario';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'El código HTML se muestra como texto y las direcciones web se transforman automáticamente.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Recordarme en este blog';
$GLOBALS['__l10n']['preview'] = 'vista previa';
$GLOBALS['__l10n']['send'] = 'enviar';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Discusiones sobre el mismo tema';
$GLOBALS['__l10n']['Trackback URL'] = 'URL de retroenlace';
$GLOBALS['__l10n']['You must provide an author name'] = 'Debe proporcionar un nombre de autor';
$GLOBALS['__l10n']['You must provide a comment'] = 'Debe escribir un comentario';
$GLOBALS['__l10n']['Email address is not valid'] = 'La dirección de correo electrónico no es válida';
$GLOBALS['__l10n']['Document not found'] = 'Documento no encontrado';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'El documento que busca no existe.';
$GLOBALS['__l10n']['Powered by %s'] = 'Funciona con %s';
$GLOBALS['__l10n']['Subscribe to'] = 'Suscribirse a';
$GLOBALS['__l10n']['What is an RSS feed?'] = '¿Qué es una fuente RSS?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Una fuente RSS recoge la información de actualizaciones de un sitio web. Proporciona el contenido de las entradas o comentarios, o un extracto de ellos, junto con un enlace a la versión completa y otros metadatos. Esta fuente tiene como objetivo ser leído por un <a href="http://es.wikipedia.org/wiki/Agregador/">agregador</a> de RSS.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Simplemente copie la siguiente dirección en su agregador:';
$GLOBALS['__l10n']['Password needed'] = 'Es necesaria una contraseña';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Debe indicar una contraseña para acceder a este área.';
$GLOBALS['__l10n']['Password:'] = 'Contraseña:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Debe proporcionar una dirección de correo electrónico válida.';
$GLOBALS['__l10n']['Read'] = 'Leer';

==> es-2.9.2.zip: es/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Ir al contenido';
$GLOBALS['__l10n']['To menu'] = 'Ir al menú';
$GLOBALS['__l10n']['To search'] = 'Ir a las búsquedas';
$GLOBALS['__l10n']['By'] = 'Por';
$GLOBALS['__l10n']['by'] = 'por';
$GLOBALS['__l10n']['on'] = 'el';
$GLOBALS['__l10n']['On'] = 'El';
$GLOBALS['__l10n']['Continue reading'] = 'Seguir leyendo';
$GLOBALS['__l10n']['no comments'] = 'sin comentarios';
$GLOBALS['__l10n']['one comment'] = 'un comentario';
$GLOBALS['__l10n']['%d comments'] = '%d comentarios';
$GLOBALS['__l10n']['no trackbacks'] = 'sin retroenlaces';
$GLOBALS['__l10n']['one trackback'] = 'un retroenlace';
$GLOBALS['__l10n']['%d trackbacks'] = '%d retroenlaces';
$GLOBALS['__l10n']['no attachments'] = 'sin adjuntos';
$GLOBALS['__l10n']['one attachment'] = 'un adjunto';
$GLOBALS['__l10n']['%d attachments'] = '%d adjuntos';
$GLOBALS['__l10n']['previous entries'] = 'entradas anteriores';
$GLOBALS['__l10n']['page'] = 'página';
$GLOBALS['__l10n']['of'] = 'de';
$GLOBALS['__l10n']['next entries'] = 'siguientes entradas';
$GLOBALS['__l10n']['Search'] = 'Buscar';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Su busqueda de <em>%1$s</em> no ha devuelto ningún resultado.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Su búsqueda de <em>%1$s</em> ha devuelto <strong>%2$s</strong> resultado.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Su búsqueda de <em>%1$s</em> ha devuelto <strong>%2$s</strong> resultados.';
$GLOBALS['__l10n']['Home'] = 'Inicio';
$GLOBALS['__l10n']['All keywords'] = 'Todas las palabras clave';
$GLOBALS['__l10n']['Best of me'] = 'Destacados';
$GLOBALS['__l10n']['Languages'] = 'Idiomas';
$GLOBALS['__l10n']['Categories'] = 'Categorías';
$GLOBALS['__l10n']['Subcategories'] = 'Subcategorías';
$GLOBALS['__l10n']['Archives'] = 'Archivos';
$GLOBALS['__l10n']['Links'] = 'Enlaces';
$GLOBALS['__l10n']['Subscribe'] = 'Suscribirse';
$GLOBALS['__l10n']['Entries feed'] = 'Fuente de las entradas';
$GLOBALS['__l10n']['Comments feed'] = 'Fuente de los comentarios';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Fuente Atom de los comentarios de este blog';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Fuente Atom de las entradas de esta categoría';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Fuente Atom de los comentarios de esta categoría';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Fuente de los comentarios de esta entrada';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Fuente Atom de los comentarios de esta entrada';
$GLOBALS['__l10n']['Attachments'] = 'Adjuntos';
$GLOBALS['__l10n']['Permalink'] = 'Enlace permanente';
$GLOBALS['__l10n']['Comments'] = 'Comentarios';
$GLOBALS['__l10n']['Your comment'] = 'Su comentario';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Su comentario ha sido publicado.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Se ha enviado su comentario, y se publicará tras ser revisado.';
$GLOBALS['__l10n']['Add a comment'] = 'Añadir un comentario';
$GLOBALS['__l10n']['Name or nickname'] = 'Nombre o apodo';
$GLOBALS['__l10n']['Email address'] = 'Dirección de correo electrónico';
$GLOBALS['__l10n']['Website'] = 'Sitio web';
$GLOBALS['__l10n']['optional'] = 'opcional';
$GLOBALS['__l10n']['Comment'] = 'Comentario';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'El código HTML se muestra como texto y las direcciones web se transforman automáticamente.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Recordarme en este blog';
$GLOBALS['__l10n']['preview'] = 'vista previa';
$GLOBALS['__l10n']['send'] = 'enviar';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Discusiones sobre el mismo tema';
$GLOBALS['__l10n']['Trackback URL'] = 'URL de retroenlace';
$GLOBALS['__l10n']['You must provide an author name'] = 'Debe proporcionar un nombre de autor';
$GLOBALS['__l10n']['You must provide a comment'] = 'Debe escribir un comentario';
$GLOBALS['__l10n']['Email address is not valid'] = 'La dirección de correo electrónico no es válida';
$GLOBALS['__l10n']['Document not found'] = 'Documento no encontrado';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'El documento que busca no existe.';
$GLOBALS['__l10n']['Powered by %s'] = 'Funciona con %s';
$GLOBALS['__l10n']['Subscribe to'] = 'Suscribirse a';
$GLOBALS['__l10n']['What is an RSS feed?'] = '¿Qué es una fuente RSS?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Una fuente RSS recoge la información de actualizaciones de un sitio web. Proporciona el contenido de las entradas o comentarios, o un extracto de ellos, junto con un enlace a la versión completa y otros metadatos. Esta fuente tiene como objetivo ser leído por un <a href="http://es.wikipedia.org/wiki/Agregador/">agregador</a> de RSS.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Simplemente copie la siguiente dirección en su agregador:';
$GLOBALS['__l10n']['Password needed'] = 'Es necesaria una contraseña';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Debe indicar una contraseña para acceder a este área.';
$GLOBALS['__l10n']['Password:'] = 'Contraseña:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Debe proporcionar una dirección de correo electrónico válida.';
$GLOBALS['__l10n']['Read'] = 'Leer';
$GLOBALS['__l10n']['toDay'] = 'al';
$GLOBALS['__l10n']['FromDay'] = 'Del';
$GLOBALS['__l10n']['By category'] = 'Por categoría';
$GLOBALS['__l10n']['By date'] = 'Por fecha';
$GLOBALS['__l10n']['By tag'] = 'Por tag';
